/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "configdlg.h"
#include "dirlistwidget.h"
#include <qlayout.h>
#include <qcheckbox.h>
#include <qspinbox.h>
#include <qlabel.h>
#include <klocale.h>
#include <kleansweepcfg.h>

KleanSweepConfigDialog::KleanSweepConfigDialog(QWidget *parent): KDialogBase(KDialogBase::Tabbed, i18n("KleanSweep settings"), KDialogBase::Apply|KDialogBase::Cancel, KDialogBase::NoDefault, parent, 0, true)
{
	setMinimumSize(500, 380);
	setupGeneralPage();
	setupOrphansPage();
}

KleanSweepConfigDialog::~KleanSweepConfigDialog()
{
}

void KleanSweepConfigDialog::setupGeneralPage()
{
	KleanSweepConfig *cfg = &KleanSweepConfig::instance();

	QFrame *page = addPage(i18n("General"));
	QVBoxLayout *lay = new QVBoxLayout(page, 0, KDialog::spacingHint());
	globalexcl = new DirListWidget(i18n("Directories to exclude (all scans)"), page);
	globalexcl->insertStringList(cfg->globalExcludePaths());
	lay->addWidget(globalexcl);
	showprogress = new QCheckBox(i18n("Show progress"), page);
	showprogress->setChecked(cfg->showProgress());
	lay->addWidget(showprogress);
	optimizesearch = new QCheckBox(i18n("Optimize single searches"), page);
	optimizesearch->setChecked(cfg->optimizeSearches());
	optimizesearch->setDisabled(true);
	lay->addWidget(optimizesearch);

	QHBoxLayout *lay1 = new QHBoxLayout(lay);
	QLabel *lunused = new QLabel(i18n("Consider file as unused if not accessed within"), page);
	oldfilesage = new QSpinBox(1, 365, 1, page);
	oldfilesage->setSuffix(" " + i18n("days"));
	oldfilesage->setValue(cfg->oldFilesAge());
	oldfilesage->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum));
	
	lay1->addWidget(lunused);
	lay1->addStretch(1);
	lay1->addWidget(oldfilesage);
}

void KleanSweepConfigDialog::setupOrphansPage()
{
	KleanSweepConfig *cfg = &KleanSweepConfig::instance();

	QFrame *page = addPage(i18n("Orphaned files searching"));
	QVBoxLayout *lay = new QVBoxLayout(page, 0, KDialog::spacingHint());
	orphincl = new DirListWidget(i18n("Directories to include"), page);
	orphincl->insertStringList(cfg->orphansIncludePaths());
	orphexcl = new DirListWidget(i18n("Directories to exclude"), page);
	orphexcl->insertStringList(cfg->orphansExcludePaths());
	lay->addWidget(orphincl);
	lay->addWidget(orphexcl);
}

void KleanSweepConfigDialog::slotApply()
{
	KleanSweepConfig *cfg = &KleanSweepConfig::instance();
	cfg->oldFilesAge(oldfilesage->value());
	cfg->globalExcludePaths(globalexcl->getAllPaths());
	cfg->orphansExcludePaths(orphexcl->getAllPaths());
	cfg->orphansIncludePaths(orphincl->getAllPaths());
	cfg->showProgress(showprogress->isChecked());
	QDialog::accept();
}

#include "configdlg.moc"
