/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "fileviewitem.h"
#include "filelistview.h"
#include "sweepfileinfo.h"
#include <kglobal.h>
#include <klocale.h>

FileViewItem::FileViewItem(FileListView *parent, SweepFileInfo *f): QCheckListItem(parent, QString::null, CheckBox), finfo(f)
{
	setColumns(parent->getColumns());
}

FileViewItem::FileViewItem(FileViewItem *parent, SweepFileInfo *f): QCheckListItem(parent, QString::null, CheckBox), finfo(f)
{
	if (FileListView *list = dynamic_cast<FileListView*>(listView()))
	{
		setColumns(list->getColumns());
	}
}

FileViewItem::~FileViewItem()
{
}

void FileViewItem::setColumns(int cols)
{
	if (finfo)
	{
		int i = 0;
		setPixmap(i, finfo->pixmap(16));
		if (cols & FileName)
			setText(i++, finfo->name());
		if (cols & FileDir)
			setText(i++, finfo->url().directory());
		if (cols & Target)
			setText(i++, finfo->getTarget());
		if (cols & Size)
			setText(i++, KGlobal::locale()->formatNumber(finfo->size(), 0));
		if (cols & ModTime)
			setText(i++, finfo->timeString(KIO::UDS_MODIFICATION_TIME));
		if (cols & AccessTime)
			setText(i++, finfo->timeString(KIO::UDS_ACCESS_TIME));
		if (cols & Permissions)
			setText(i++, finfo->permissionsString());
		if (cols & Owner)
			setText(i++, finfo->user());
		if (cols & Group)
			setText(i++, finfo->group());
		setOn(finfo->isMarkedForRemoval());
	}
}

SweepFileInfo* FileViewItem::fileItem() const
{
	return finfo;
}

void FileViewItem::stateChange(bool f)
{
	if (finfo && finfo->isMarkedForRemoval() != f)
	{
		finfo->markForRemoval(f);
		if (FileListView *list = dynamic_cast<FileListView*>(listView()))
			list->stateChanged(finfo, f);
	}
}

int FileViewItem::compare(QListViewItem *i, int col, bool ascending) const
{
	if (FileListView *list = dynamic_cast<FileListView*>(listView()))
	{
		if (list->getColumnType(col) == Size)
		{
			if (FileViewItem *item = dynamic_cast<FileViewItem*>(i))
			{
				return finfo->size() - item->finfo->size();
			}
		}
		return QListViewItem::compare(i, col, ascending);
	}
}

